package com.ruoyi.system.service;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.system.domain.communityNews.CommunityNews;
import com.ruoyi.system.domain.communityNews.vo.CommentInteractionVo;

import java.util.List;


/**
 * 社区资讯Service接口
 * 
 * @author boman
 * @date 2025-02-14
 */
public interface ICommunityNewsService 
{
    /**
     * 查询社区资讯
     * 
     * @param communityId 社区资讯主键
     * @return 社区资讯
     */
    public CommunityNews selectCommunityNewsByCommunityId(Long communityId);

    /**
     * 查询社区资讯列表
     * 
     * @param communityNews 社区资讯
     * @return 社区资讯集合
     */
    public List<CommunityNews> selectCommunityNewsList(CommunityNews communityNews);

    /**
     * 新增社区资讯
     * 
     * @param communityNews 社区资讯
     * @return 结果
     */
    public int insertCommunityNews(CommunityNews communityNews);

    /**
     * 修改社区资讯
     * 
     * @param communityNews 社区资讯
     * @return 结果
     */
    public int updateCommunityNews(CommunityNews communityNews);

    /**
     * 批量删除社区资讯 等于把资讯关闭status = 2
     * 
     * @param communityIds 需要删除的社区资讯主键集合
     * @return 结果
     */
    public int deleteCommunityNewsByCommunityIds(Long[] communityIds);

    /**
     * 删除社区资讯信息
     * 
     * @param communityId 社区资讯主键
     * @return 结果
     */
    public int deleteCommunityNewsByCommunityId(Long communityId);

    /**
     * 设置未读互动
     * @param commentInteractionVo 接收未读互动的参数
     */
    public void setCommentInteraction(CommentInteractionVo commentInteractionVo);

    /**
     * 获取未读互动列表
     * @param commentInteractionVo
     * @return
     */
    public AjaxResult getCommentInteraction(CommentInteractionVo commentInteractionVo);

    /**
     * 获取未读互动数量
     * @param commentInteractionVo
     * @return
     */
    public AjaxResult getCommentInteractionCount(CommentInteractionVo commentInteractionVo);
}
